/*
 * Copyright 2015 Canonical Ltd.
 *
 * This file is part of webbrowser-app.
 *
 * webbrowser-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * webbrowser-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "inactivity-timer.h"
#include "service.h"

#include <QCoreApplication>
#include <QDBusConnection>
#include <QDBusMetaType>

using namespace CookieService;

int main(int argc, char **argv)
{
    QCoreApplication app(argc, argv);

    qDBusRegisterMetaType<CookieService::Cookies>();

    Service *service = new Service();
    QDBusConnection connection = QDBusConnection::sessionBus();
    connection.registerObject(COOKIE_SERVICE_OBJECT_PATH, service);
    connection.registerService(COOKIE_SERVICE_SERVICE_NAME);

    InactivityTimer *inactivityTimer = new InactivityTimer(5 * 1000);
    inactivityTimer->watchObject(service);
    QObject::connect(inactivityTimer, SIGNAL(timeout()),
                     &app, SLOT(quit()));

    int ret = app.exec();

    connection.unregisterService(COOKIE_SERVICE_SERVICE_NAME);
    connection.unregisterObject(COOKIE_SERVICE_OBJECT_PATH);
    delete service;

    delete inactivityTimer;

    return ret;
}

