/*
 * Copyright 2015 Canonical Ltd.
 *
 * This file is part of webbrowser-app.
 *
 * webbrowser-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * webbrowser-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef COOKIE_SERVICE_SERVICE_H
#define COOKIE_SERVICE_SERVICE_H

#include <QDBusContext>
#include <QObject>
#include <QVariantMap>

#define COOKIE_SERVICE_SERVICE_NAME "com.canonical.cookie-sharing"
#define COOKIE_SERVICE_OBJECT_PATH "/"

namespace CookieService {

typedef QString Cookies;

class ServicePrivate;
class Service: public QObject, protected QDBusContext
{
    Q_OBJECT
    Q_PROPERTY(bool isIdle READ isIdle NOTIFY isIdleChanged)
    Q_CLASSINFO("D-Bus Interface", "com.canonical.cookie-sharing")

public:
    explicit Service(QObject *parent = 0);
    ~Service();

    bool isIdle() const;

public Q_SLOTS:
    void saveCookies(const QString &path, const Cookies &cookies);
    Cookies loadCookies(const QString &path);

Q_SIGNALS:
    void isIdleChanged();

private:
    ServicePrivate *d_ptr;
    Q_DECLARE_PRIVATE(Service)
};

} // namespace

#endif // COOKIE_SERVICE_SERVICE_H
